Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Config ¶
type Config struct {
LocalMode bool
RabbitConfig *RabbitMQConfig
}
Config is the config used to intialize workers
type RabbitMQConfig ¶
type RabbitMQConfig struct {
UserName string
Password string
BrokerVHost string
Host string
Port string
QueueName string
}
RabbitMQConfig is the config used for scheduling tasks through rabbitmq
type ScheduleConfig ¶
type ScheduleConfig struct {
// contains filtered or unexported fields
}
ScheduleConfig is the config used when scheduling a task
type ScheduleOption ¶
type ScheduleOption func(*ScheduleConfig)
ScheduleOption represents different options available for Schedule
func WithQueueName ¶
func WithQueueName(queueName string) ScheduleOption
WithQueueName sets the destination queue for this task
func WithRetry ¶
func WithRetry(n int) ScheduleOption
WithRetry sets the number of Retries for this task
Click to show internal directories.
Click to hide internal directories.